Class npgeom is used to store data that will be
processed as those of a nonparametric geometric mixture.
Function npgeom creates an object of class npgeom,
given values and weights/frequencies.
Function rnpgeom generates a random sample from a geometric
mixture and saves the data as an object of class npgeom.
Function dnpgeom is the density function of a Poisson
mixture.
Function pnpgeom is the distribution function of a Poisson
mixture.